==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/0d/0d1e8dbd5bbba9976ad98a56fc7d1b92.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PointBundle/Event/GroupScoreChangeEvent.php */
class __TwigTemplate_6fc50695e8346e6546dfa9462675ec52 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\PointBundle\\Event;

use Mautic\\LeadBundle\\Entity\\Lead;
use Mautic\\PointBundle\\Entity\\GroupContactScore;

final class GroupScoreChangeEvent
{
    public function __construct(
        private GroupContactScore \$groupContactScore,
        private int \$oldScore,
        private int \$newScore
    ) {
    }

    public function getGroupContactScore(): GroupContactScore
    {
        return \$this->groupContactScore;
    }

    public function getContact(): Lead
    {
        return \$this->groupContactScore->getContact();
    }

    public function getNewScore(): int
    {
        return \$this->newScore;
    }

    public function getOldScore(): int
    {
        return \$this->oldScore;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PointBundle/Event/GroupScoreChangeEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PointBundle/Event/GroupScoreChangeEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/PointBundle/Event/GroupScoreChangeEvent.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/0d/0d1e8dbd5bbba9976ad98a56fc7d1b92.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PointBundle/Event/GroupScoreChangeEvent.php */
class __TwigTemplate_6fc50695e8346e6546dfa9462675ec52 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\PointBundle\\Event;

use Mautic\\LeadBundle\\Entity\\Lead;
use Mautic\\PointBundle\\Entity\\GroupContactScore;

final class GroupScoreChangeEvent
{
    public function __construct(
        private GroupContactScore \$groupContactScore,
        private int \$oldScore,
        private int \$newScore
    ) {
    }

    public function getGroupContactScore(): GroupContactScore
    {
        return \$this->groupContactScore;
    }

    public function getContact(): Lead
    {
        return \$this->groupContactScore->getContact();
    }

    public function getNewScore(): int
    {
        return \$this->newScore;
    }

    public function getOldScore(): int
    {
        return \$this->oldScore;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PointBundle/Event/GroupScoreChangeEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PointBundle/Event/GroupScoreChangeEvent.php", "/var/www/html/production-demo/app/bundles/PointBundle/Event/GroupScoreChangeEvent.php");
    }
}
